import 'dart:ffi';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:wl_base_help/wl_base_help.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({super.key});

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';
  String _isRunAdminEerr = 'Unknown';
  String _isAdmin = 'no';
  String _isRunPassName = 'no';
  final _wlBaseHelpPlugin = WlBaseHelp();

  @override
  void initState() {
    super.initState();
    initPlatformState();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    // We also handle the message potentially returning null.
    try {
      platformVersion =
          await _wlBaseHelpPlugin.getPlatformVersion() ?? 'Unknown platform version';
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  Future<void> onRunAdmin() async {
    String isRunadminErore;
    try {
      isRunadminErore = await _wlBaseHelpPlugin.runAsAdministrator() ?? 'error';
    } on PlatformException {
      isRunadminErore = 'error';
    }
    setState(() {
      _isRunAdminEerr = isRunadminErore;
    });
  }

  Future<void> onIsRunAdmin() async {
    bool isAdmin;
    try {
      isAdmin = await _wlBaseHelpPlugin.isRunningAsAdmin() ?? false;
    } on PlatformException {
      isAdmin = false;
      _isAdmin = 'error';
      setState(() {} );
    }
    setState(() {
      _isAdmin = isAdmin ? 'yes' : 'no';
    });
  }

  Future<void> onisProcessRunning(String passName) async {
    bool isRun;
    try {
      isRun = await _wlBaseHelpPlugin.isProcessRunning(passName) ?? false;
    } on PlatformException {
      isRun = false;
      _isRunPassName = 'error';
      setState(() {} );
    }
    setState(() {
      _isRunPassName = isRun ? 'yes' : 'no';
    });
  }

  Future<void> onkillProcess(String passName) async {

    try {
      await _wlBaseHelpPlugin.killProcess(passName);
    } on PlatformException {
      setState(() {} );
    }

  }
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: Row(
            children: [
              Text('Running on: $_platformVersion\n'),
              const SizedBox(
                height: 20,
              ),
              // Text('Running on: $_isRunAdminEerr\n'),
              ElevatedButton(
                  onPressed: onRunAdmin, child: const Text("管理员重启")),

              ElevatedButton(
                  onPressed: onIsRunAdmin, child: Text(_isAdmin)),

              ElevatedButton(
                  onPressed: () async{
                    await _wlBaseHelpPlugin.showConsole();
                  }, child: Text('显示控制台')),
              ElevatedButton(
                  onPressed: () async{
                    await _wlBaseHelpPlugin.hideConsole();
                  }, child: Text('隐藏控制台')),

              ElevatedButton(
                  onPressed: () async{
                    await onisProcessRunning('dart.exe');
                  }, child: Text(_isRunPassName)),
              ElevatedButton(
                  onPressed: () async{
                    await onkillProcess('IDMan.exe');
                  }, child: Text('隐藏控制台')),
            ],
          ),
        ),
      ),
    );
  }
}
