import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'wl_base_help_platform_interface.dart';

/// An implementation of [WlBaseHelpPlatform] that uses method channels.
class MethodChannelWlBaseHelp extends WlBaseHelpPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('wl_base_help');

  @override
  Future<String?> getPlatformVersion() async {
    final version = await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<String?> runAsAdministrator() async {
    try {
      await methodChannel.invokeMethod('runAsAdministrator');
      return null;
    } on PlatformException catch (e) {
      return e.code;
    }
  }
  @override
  Future<bool?> isRunningAsAdmin() async {
    final isAdmin = await methodChannel.invokeMethod<bool>('isRunningAsAdmin');
    return isAdmin;
  }
  @override
  Future<void> showConsole() async {
    await methodChannel.invokeMethod('showConsole');
  }
  @override
  Future<void> hideConsole() async {
    await methodChannel.invokeMethod('hideConsole');
  }
  @override
  Future<bool?> isProcessRunning(String processName) async {
    final isRunning = await methodChannel.invokeMethod('isProcessRunning', {'processName': processName});
    return isRunning;
  }

  @override
  Future<void> killProcess(String processName) async {
    await methodChannel.invokeMethod('killProcess', {'processName': processName});
  }
}
